/*********************************************************************
*               SEGGER MICROCONTROLLER SYSTEME GmbH                  *
*       Solutions for real time microcontroller applications         *
**********************************************************************
*                                                                    *
*       (C) 2006   SEGGER Microcontroller Systeme GmbH               *
*                                                                    *
*       www.segger.com     Support: support@segger.com               *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS version: 3.32e                                         *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File        : CPUM16C.h
Purpose     : SFR defines in ANSI C
---------------------------END-OF-HEADER------------------------------
*/

#ifndef CPUM16C_H  /* Avoid multiple inclusion */
#define CPUM16C_H

/********************  Processor Registers  ***********************/

#define PM         (*(volatile unsigned int* )0x004)   /* Processor Mode Register */
#define PM0        (*(volatile unsigned char*)0x004)   /* Processor Mode Register 0 */
#define PM1        (*(volatile unsigned char*)0x005)   /* Processor Mode Register 1 */
#define CM0        (*(volatile unsigned char*)0x006)   /* System clock control register 0 */
#define CM1        (*(volatile unsigned char*)0x007)   /* System clock control register 1 */
#define CM         (*(volatile unsigned int* )0x006)   /* System clock control register */
#define CSR        (*(volatile unsigned char*)0x008)   /* Chip select control register */


/*******************  Watchdog Timer  ****************************/

#define WDTS       (*(volatile unsigned char*)0x00E)   /* Watchdog timer start register */
#define WDC        (*(volatile unsigned char*)0x00F)   /* Watchdog timer control register */


/*******************  Interrupt Control Register  ****************/

#define AIER       (*(volatile unsigned char*)0x009)   /* Address match interrupt enable */
#define PRCR       (*(volatile unsigned char*)0x00A)   /* Protect register */
#define RMAD00     (*(volatile unsigned char*)0x010)   /* Address match interrupt register 0 (low) */
#define RMAD01     (*(volatile unsigned char*)0x011)   /* Address match interrupt register 0 (mid) */
#define RMAD02     (*(volatile unsigned char*)0x012)   /* Address match interrupt register 0 (high)*/
#define RMAD10     (*(volatile unsigned char*)0x014)   /* Address match interrupt register 1 (low) */
#define RMAD11     (*(volatile unsigned char*)0x015)   /* Address match interrupt register 1 (mid) */
#define RMAD12     (*(volatile unsigned char*)0x016)   /* Address match interrupt register 1 (high)*/
#define DMA0IC     (*(volatile unsigned char*)0x04B)   /* DMA0 interrupt control register */
#define DMA1IC     (*(volatile unsigned char*)0x04C)   /* DMA1 interrupt control register */
#define KUPIC      (*(volatile unsigned char*)0x04D)   /* Key input interrupt control register */
#define S0TIC      (*(volatile unsigned char*)0x051)   /* UART0 transmit interrupt control register*/
#define S0RIC      (*(volatile unsigned char*)0x052)   /* UART0 receive interrupt control register */
#define S1TIC      (*(volatile unsigned char*)0x053)   /* UART1 transmit interrupt control register*/
#define S1RIC      (*(volatile unsigned char*)0x054)   /* UART1 receive interrupt control register */
#define TA0IC      (*(volatile unsigned char*)0x055)   /* Timer A0 interrupt control register */
#define TA1IC      (*(volatile unsigned char*)0x056)   /* Timer A1 interrupt control register */
#define TA2IC      (*(volatile unsigned char*)0x057)   /* Timer A2 interrupt control register */
#define TA3IC      (*(volatile unsigned char*)0x058)   /* Timer A3 interrupt control register */
#define TA4IC      (*(volatile unsigned char*)0x059)   /* Timer A4 interrupt control register */
#define TB0IC      (*(volatile unsigned char*)0x05A)   /* Timer B0 interrupt control register */
#define TB1IC      (*(volatile unsigned char*)0x05B)   /* Timer B1 interrupt control register */
#define TB2IC      (*(volatile unsigned char*)0x05C)   /* Timer B2 interrupt control register */
#define INT0IC     (*(volatile unsigned char*)0x05D)   /* Interrupt 0 interrupt control register */
#define INT1IC     (*(volatile unsigned char*)0x05E)   /* Interrupt 1 interrupt control register */
#define INT2IC     (*(volatile unsigned char*)0x05F)   /* Interrupt 2 interrupt control register */


/*******************  DMA Registers  *****************************/

#define SAR00      (*(volatile unsigned char*)0x020)   /* DMA0 source pointer (low) */
#define SAR01      (*(volatile unsigned char*)0x021)   /* DMA0 source pointer (mid) */
#define SAR02      (*(volatile unsigned char*)0x022)   /* DMA0 source pointer (high) */
#define DAR00      (*(volatile unsigned char*)0x024)   /* DMA0 destination pointer (low) */
#define DAR01      (*(volatile unsigned char*)0x025)   /* DMA0 destination pointer (mid) */
#define DAR02      (*(volatile unsigned char*)0x026)   /* DMA0 destination pointer (high) */
#define TCR00      (*(volatile unsigned char*)0x028)   /* DMA0 transfer counter (low) */
#define TCR01      (*(volatile unsigned char*)0x029)   /* DMA0 transfer counter (high) */
#define TCR0       (*(volatile unsigned int* )0x028)   /* DMA0 transfer counter */
#define DM0CON     (*(volatile unsigned char*)0x02C)   /* DMA0 control register */

#define SAR10      (*(volatile unsigned char*)0x030)   /* DMA1 source pointer (low) */
#define SAR11      (*(volatile unsigned char*)0x031)   /* DMA1 source pointer (mid) */
#define SAR12      (*(volatile unsigned char*)0x032)   /* DMA1 source pointer (high) */
#define DAR10      (*(volatile unsigned char*)0x034)   /* DMA1 destination pointer (low) */
#define DAR11      (*(volatile unsigned char*)0x035)   /* DMA1 destination pointer (mid) */
#define DAR12      (*(volatile unsigned char*)0x036)   /* DMA1 destination pointer (high) */
#define TCR10      (*(volatile unsigned char*)0x038)   /* DMA1 transfer counter (low) */
#define TCR11      (*(volatile unsigned char*)0x039)   /* DMA1 transfer counter (high) */
#define TCR1       (*(volatile unsigned int* )0x038)   /* DMA1 transfer counter */
#define DM1CON     (*(volatile unsigned char*)0x03C)   /* DMA1 control register */

#define DM0SL      (*(volatile unsigned char*)0x3B8)   /* DMA0 cause selection */
#define DM1SL      (*(volatile unsigned char*)0x3BA)   /* DMA1 cause selection */


/*******************  Timer Registers  ***************************/

#define TABSR      (*(volatile unsigned char*)0x380)   /* Timer A/B count start flags */
#define CPSRF      (*(volatile unsigned char*)0x381)   /* Clock prescaler reset flag */
#define ONSF       (*(volatile unsigned char*)0x382)   /* One-shot start flagl */
#define TRGSR      (*(volatile unsigned char*)0x383)   /* Trigger select register */
#define UDF        (*(volatile unsigned char*)0x384)   /* Up- down-count selection flag */

#define TA0L       (*(volatile unsigned char*)0x386)   /* Timer A0 (low byte) */
#define TA0H       (*(volatile unsigned char*)0x387)   /* Timer A0 (high byte) */
#define TA0        (*(volatile unsigned int* )0x386)   /* Timer A0 */
#define TA1L       (*(volatile unsigned char*)0x388)   /* Timer A1 (low byte) */
#define TA1H       (*(volatile unsigned char*)0x389)   /* Timer A1 (high byte) */
#define TA1        (*(volatile unsigned int* )0x388)   /* Timer A1 */
#define TA2L       (*(volatile unsigned char*)0x38A)   /* Timer A2 (low byte) */
#define TA2H       (*(volatile unsigned char*)0x38B)   /* Timer A2 (high byte) */
#define TA2        (*(volatile unsigned int* )0x38A)   /* Timer A2 */
#define TA3L       (*(volatile unsigned char*)0x38C)   /* Timer A3 (low byte) */
#define TA3H       (*(volatile unsigned char*)0x38D)   /* Timer A3 (high byte) */
#define TA3        (*(volatile unsigned int* )0x38C)   /* Timer A3 */
#define TA4L       (*(volatile unsigned char*)0x38E)   /* Timer A4 (low byte) */
#define TA4H       (*(volatile unsigned char*)0x38F)   /* Timer A4 (high byte) */
#define TA4        (*(volatile unsigned int* )0x38E)   /* Timer A4 */
#define TB0L       (*(volatile unsigned char*)0x390)   /* Timer B0 (low byte) */
#define TB0H       (*(volatile unsigned char*)0x391)   /* Timer B0 (high byte) */
#define TB0        (*(volatile unsigned int* )0x390)   /* Timer B0 */
#define TB1L       (*(volatile unsigned char*)0x392)   /* Timer B1 (low byte) */
#define TB1H       (*(volatile unsigned char*)0x393)   /* Timer B1 (high byte) */
#define TB1        (*(volatile unsigned int* )0x392)   /* Timer B1 */
#define TB2L       (*(volatile unsigned char*)0x394)   /* Timer B2 (low byte) */
#define TB2H       (*(volatile unsigned char*)0x395)   /* Timer B2 (high byte) */
#define TB2        (*(volatile unsigned int* )0x394)   /* Timer B2 */

#define TA0MR      (*(volatile unsigned char*)0x396)   /* Timer A0 mode register */
#define TA1MR      (*(volatile unsigned char*)0x397)   /* Timer A1 mode register */
#define TA2MR      (*(volatile unsigned char*)0x398)   /* Timer A2 mode register */
#define TA3MR      (*(volatile unsigned char*)0x399)   /* Timer A3 mode register */
#define TA4MR      (*(volatile unsigned char*)0x39A)   /* Timer A4 mode register */
#define TB0MR      (*(volatile unsigned char*)0x39B)   /* Timer B0 mode register */
#define TB1MR      (*(volatile unsigned char*)0x39C)   /* Timer B1 mode register */
#define TB2MR      (*(volatile unsigned char*)0x39D)   /* Timer B2 mode register */


/*******************  UART Registers  ****************************/

#define U0MR       (*(volatile unsigned char*)0x3A0)   /* UART 0 mode register */
#define U0BRG      (*(volatile unsigned char*)0x3A1)   /* UART 0 baud rate generator */
#define U0TBL      (*(volatile unsigned char*)0x3A2)   /* UART 0 transmit buffer (low byte) */
#define U0TBH      (*(volatile unsigned char*)0x3A3)   /* UART 0 transmit buffer (high byte) */
#define U0TB       (*(volatile unsigned int* )0x3A2)   /* UART 0 transmit buffer */
#define U0C0       (*(volatile unsigned char*)0x3A4)   /* UART 0 control register 0 */
#define U0C1       (*(volatile unsigned char*)0x3A5)   /* UART 0 control register 1 */
#define U0C        (*(volatile unsigned int* )0x3A4)   /* UART 0 control register */
#define U0RBL      (*(volatile unsigned char*)0x3A6)   /* UART 0 receive buffer (low byte) */
#define U0RBH      (*(volatile unsigned char*)0x3A7)   /* UART 0 receive buffer (high byte) */
#define U0RB       (*(volatile unsigned int* )0x3A6)   /* UART 0 receive buffer */

#define U1MR       (*(volatile unsigned char*)0x3A8)   /* UART 1 mode register */
#define U1BRG      (*(volatile unsigned char*)0x3A9)   /* UART 1 baud rate generator */
#define U1TBL      (*(volatile unsigned char*)0x3AA)   /* UART 1 transmit buffer (low byte) */
#define U1TBH      (*(volatile unsigned char*)0x3AB)   /* UART 1 transmit buffer (high byte) */
#define U1TB       (*(volatile unsigned int* )0x3AA)   /* UART 1 transmit buffer */
#define U1C0       (*(volatile unsigned char*)0x3AC)   /* UART 1 control register 0 */
#define U1C1       (*(volatile unsigned char*)0x3AD)   /* UART 1 control register 1 */
#define U1C        (*(volatile unsigned int* )0x3AC)   /* UART 1 control register */
#define U1RBL      (*(volatile unsigned char*)0x3AE)   /* UART 1 receive buffer (low byte) */
#define U1RBH      (*(volatile unsigned char*)0x3AF)   /* UART 1 receive buffer (high byte) */
#define U1RB       (*(volatile unsigned int* )0x3AE)   /* UART 1 receive buffer */
#define UCON       (*(volatile unsigned char*)0x3B0)   /* UART control register 2 */


/*******************  CRC register  ******************************/

#define CRCDL      (*(volatile unsigned char*)0x3BC)   /* CRC data register (low byte) */
#define CRCDH      (*(volatile unsigned char*)0x3BD)   /* CRC data register (high byte) */
#define CRCD       (*(volatile unsigned int* )0x3BC)   /* CRC data register */
#define CRCIN      (*(volatile unsigned char*)0x3BE)   /* CRC input register */


/*******************  A/D Converter  *****************************/

#define AD0L       (*(volatile unsigned char*)0x3C0)   /* A/D register 0 (low byte) */
#define AD0H       (*(volatile unsigned char*)0x3C1)   /* A/D register 0 (high byte) */
#define AD0        (*(volatile unsigned int* )0x3C0)   /* A/D register 0 */
#define AD1L       (*(volatile unsigned char*)0x3C2)   /* A/D register 1 (low byte) */
#define AD1H       (*(volatile unsigned char*)0x3C3)   /* A/D register 1 (high byte) */
#define AD1        (*(volatile unsigned int* )0x3C2)   /* A/D register 1 */
#define AD2L       (*(volatile unsigned char*)0x3C4)   /* A/D register 2 (low byte) */
#define AD2H       (*(volatile unsigned char*)0x3C5)   /* A/D register 2 (high byte) */
#define AD2        (*(volatile unsigned int* )0x3C4)   /* A/D register 2 */
#define AD3L       (*(volatile unsigned char*)0x3C6)   /* A/D register 3 (low byte) */
#define AD3H       (*(volatile unsigned char*)0x3C7)   /* A/D register 3 (high byte) */
#define AD3        (*(volatile unsigned int* )0x3C6)   /* A/D register 3 */
#define AD4L       (*(volatile unsigned char*)0x3C8)   /* A/D register 4 (low byte) */
#define AD4H       (*(volatile unsigned char*)0x3C9)   /* A/D register 4 (high byte) */
#define AD4        (*(volatile unsigned int* )0x3C8)   /* A/D register 4 */
#define AD5L       (*(volatile unsigned char*)0x3CA)   /* A/D register 5 (low byte) */
#define AD5H       (*(volatile unsigned char*)0x3CB)   /* A/D register 5 (high byte) */
#define AD5        (*(volatile unsigned int* )0x3CA)   /* A/D register 5 */
#define AD6L       (*(volatile unsigned char*)0x3CC)   /* A/D register 6 (low byte) */
#define AD6H       (*(volatile unsigned char*)0x3CD)   /* A/D register 6 (high byte) */
#define AD6        (*(volatile unsigned int* )0x3CC)   /* A/D register 6 */
#define AD7L       (*(volatile unsigned char*)0x3CE)   /* A/D register 7 (low byte) */
#define AD7H       (*(volatile unsigned char*)0x3CF)   /* A/D register 7 (high byte) */
#define AD7        (*(volatile unsigned int* )0x3CE)   /* A/D register 7 */

#define ADCON0     (*(volatile unsigned char*)0x3D6)   /* A/D control register 0 */
#define ADCO10     (*(volatile unsigned char*)0x3D7)   /* A/D control register 1 */
#define ADCON      (*(volatile unsigned int* )0x3D6)   /* A/D control register */


/*******************  D-A Converter  *****************************/

#define DA0        (*(volatile unsigned char*)0x3D8)   /* D-A register 0 */
#define DA1        (*(volatile unsigned char*)0x3DA)   /* D-A register 1 */
#define DAC        (*(volatile unsigned char*)0x3DC)   /* D-A control register */


/*******************  Port Registers  ***************************/

#define P0         (*(volatile unsigned char*)0x3E0)   /* Port P0 register */
#define P1         (*(volatile unsigned char*)0x3E1)   /* Port P1 register */
#define P01        (*(volatile unsigned int* )0x3E0)   /* Port P0 and P1 register */
#define P0D        (*(volatile unsigned char*)0x3E2)   /* Port P0 direction register */
#define P1D        (*(volatile unsigned char*)0x3E3)   /* Port P1 direction register */
#define P01D       (*(volatile unsigned char*)0x3E2)   /* Port P0 and P1 direction register */
#define P2         (*(volatile unsigned char*)0x3E4)   /* Port P2 register */
#define P3         (*(volatile unsigned char*)0x3E5)   /* Port P3 register */
#define P23        (*(volatile unsigned int* )0x3E4)   /* Port P2 and P3 register */
#define P2D        (*(volatile unsigned char*)0x3E6)   /* Port P2 direction register */
#define P3D        (*(volatile unsigned char*)0x3E7)   /* Port P3 direction register */
#define P23D       (*(volatile unsigned char*)0x3E6)   /* Port P2 and P3 direction register */
#define P4         (*(volatile unsigned char*)0x3E8)   /* Port P4 register */
#define P5         (*(volatile unsigned char*)0x3E9)   /* Port P5 register */
#define P45        (*(volatile unsigned int* )0x3E8)   /* Port P4 and P5 register */
#define P4D        (*(volatile unsigned char*)0x3EA)   /* Port P4 direction register */
#define P5D        (*(volatile unsigned char*)0x3EB)   /* Port P5 direction register */
#define P45D       (*(volatile unsigned char*)0x3EA)   /* Port P4 and P5 direction register */
#define P6         (*(volatile unsigned char*)0x3EC)   /* Port P6 register */
#define P7         (*(volatile unsigned char*)0x3ED)   /* Port P7 register */
#define P67        (*(volatile unsigned int* )0x3EC)   /* Port P6 and P7 register */
#define P6D        (*(volatile unsigned char*)0x3EE)   /* Port P6 direction register */
#define P7D        (*(volatile unsigned char*)0x3EF)   /* Port P7 direction register */
#define P67D       (*(volatile unsigned char*)0x3EE)   /* Port P6 and P7 direction register */
#define P8         (*(volatile unsigned char*)0x3F0)   /* Port P8 register */
#define P9         (*(volatile unsigned char*)0x3F1)   /* Port P9 register */
#define P89        (*(volatile unsigned int* )0x3F0)   /* Port P8 and P9 register */
#define P8D        (*(volatile unsigned char*)0x3F2)   /* Port P8 direction register */
#define P9D        (*(volatile unsigned char*)0x3F3)   /* Port P9 direction register */
#define P89D       (*(volatile unsigned char*)0x3F2)   /* Port P8 and P9 direction register */
#define P10        (*(volatile unsigned char*)0x3F4)   /* Port P10 register */
#define P10D       (*(volatile unsigned char*)0x3F6)   /* Port P10 direction register */

#define PUR0       (*(volatile unsigned char*)0x3FC)   /* Pull-up register 0 */
#define PUR1       (*(volatile unsigned char*)0x3FD)   /* Pull-up register 1 */
#define PUR01      (*(volatile unsigned int* )0x3FC)   /* Pull-up register 0 and 1 */
#define PUR2       (*(volatile unsigned char*)0x3FE)   /* Pull-up register 2 */
#define PUR3       (*(volatile unsigned char*)0x3FF)   /* Pull-up register 3 */
#define PUR23      (*(volatile unsigned int* )0x3FE)   /* Pull-up register 2 and 3 */


/********************************************************************/

#endif /* Avoid multiple inclusion */

/****** EOF *********************************************************/
